@@ -1,7 +1,7 @@
 /*
  *  methods for encryption/security mechanisms for cryptmount
- *  $Revision: 169 $, $Date: 2007-07-15 06:46:54 +0100 (Sun, 15 Jul 2007) $
- *  Copyright 2005-2007 RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -460,6 +456,7 @@ static int kmgcry_needs_pw(const keyinfo_t *keyinf)
 
 
 static int kmgcry_get_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             unsigned char **key, int *keylen, FILE *fp_key)
     /* extract key from libgcrypt-encrypted file */
 {   gcry_cipher_hd_t chd;
@@ -476,13 +473,8 @@ static int kmgcry_get_key(const char *ident, const keyinfo_t *keyinfo,
     if (eflag != ERR_NOERROR) goto bail_out;
     gcry_cipher_algo_info(cipher, GCRYCTL_GET_BLKLEN, NULL, &cblksz);
 
-#ifdef TESTING
-    passwd = (char*)malloc((size_t)1024);
-    strncpy(passwd, (test_ctxtptr->argpassword[0] != NULL ? test_ctxtptr->argpassword[0] : ""),
-            1024);
-#else
-    if (km_get_passwd(ident, &passwd, 0, 0) != ERR_NOERROR) goto bail_out;
-#endif
+    eflag = km_get_passwd(ident, pw_ctxt, &passwd, 0, 0);
+    if (eflag != ERR_NOERROR) goto bail_out;
 
     /* read key header: */
     fread((void*)hbuff, (size_t)1, kmgcry_maglen, fp_key);
@@ -524,9 +516,17 @@ static int kmgcry_get_key(const char *ident, const keyinfo_t *keyinfo,
 
     /* verify checksum: */
     if (!km_aug_verify(buff, (unsigned)*keylen, &chksum0, &chksum)) {
-        fprintf(stderr, "checksum mismatch in keyfile (gcry, %x != %x)\n",
-            (unsigned)chksum, (unsigned)chksum0);
-        eflag = ERR_BADFILE;
+        switch (pw_ctxt->debug_level) {
+            case 0:
+                fprintf(stderr, _("password mismatch when extracting key\n"));
+                break;
+            case 1:     /* fall through... */
+            default:
+                fprintf(stderr, _("checksum mismatch in keyfile (gcry, %x != %x)\n"),
+                        (unsigned)chksum, (unsigned)chksum0);
+                break;
+        }
+        eflag = ERR_BADDECRYPT;
     }
 
     if (keyinfo->maxlen > 0 && *keylen > keyinfo->maxlen) {
@@ -538,19 +538,21 @@ static int kmgcry_get_key(const char *ident, const keyinfo_t *keyinfo,
     if (ferror(fp_key) != 0) {
         fprintf(stderr, _("key-extraction failed for \"%s\"\n"),
                 keyinfo->filename);
-        eflag = ERR_BADDECRYPT;
+        eflag = ERR_BADFILE;
     }
 
   bail_out:
 
-    if (buff != NULL) sec_free(buff);
-    if (hbuff != NULL) sec_free(hbuff);
+    if (buff != NULL) sec_free((void*)buff);
+    if (passwd != NULL) sec_free((void*)passwd);
+    if (hbuff != NULL) sec_free((void*)hbuff);
 
     return eflag;
 }
 
 
 static int kmgcry_put_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
     /* store key in libgcrypt-encrypted file */
 {   gcry_cipher_hd_t chd;
@@ -563,13 +565,8 @@ static int kmgcry_put_key(const char *ident, const keyinfo_t *keyinfo,
     if (eflag != ERR_NOERROR) goto bail_out;
     gcry_cipher_algo_info(cipher, GCRYCTL_GET_BLKLEN, NULL, &cblksz);
 
-#ifdef TESTING
-    passwd = sec_realloc((void*)passwd, (size_t)1024);
-    strncpy(passwd, (test_ctxtptr->argpassword[1] != NULL ? test_ctxtptr->argpassword[1] : ""),
-            1024);
-#else
-    if (km_get_passwd(ident, &passwd, 1, 1) != ERR_NOERROR) goto bail_out;
-#endif
+    eflag = km_get_passwd(ident, pw_ctxt, &passwd, 1, 1);
+    if (eflag != ERR_NOERROR) goto bail_out;
 
     /* write key header: */
     wrcnt = 0;
@@ -601,14 +598,14 @@ static int kmgcry_put_key(const char *ident, const keyinfo_t *keyinfo,
 
     if (wrcnt != (4 + buffsz / cblksz)) {
         fprintf(stderr, _("failed to create new key file\n"));
-	fprintf(stderr, "wrcnt=%d\n", (int)wrcnt);
+        fprintf(stderr, "wrcnt=%d\n", (int)wrcnt);
         eflag = ERR_BADFILE;
         goto bail_out;
     }
 
   bail_out:
-    if (buff != NULL) sec_free(buff);
-    if (passwd != NULL) sec_free(passwd);
+    if (buff != NULL) sec_free((void*)buff);
+    if (passwd != NULL) sec_free((void*)passwd);
 
     return eflag;
 }
@@ -617,6 +614,7 @@ static int kmgcry_put_key(const char *ident, const keyinfo_t *keyinfo,
 #if USE_GCRYOSSL
 
 static int kmgcryossl_get_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             unsigned char **key, int *keylen, FILE *fp_key)
     /* extract key from OpenSSL-compatible file via libgcrypt */
 {   gcry_cipher_hd_t chd;
@@ -632,13 +630,8 @@ static int kmgcryossl_get_key(const char *ident, const keyinfo_t *keyinfo,
     if (eflag != ERR_NOERROR) goto bail_out;
     gcry_cipher_algo_info(cipher, GCRYCTL_GET_BLKLEN, NULL, &cblksz);
 
-#ifdef TESTING
-    passwd = (char*)malloc((size_t)1024);
-    strncpy(passwd, (test_ctxtptr->argpassword[0] != NULL ? test_ctxtptr->argpassword[0] : ""),
-            1024);
-#else
-    if (km_get_passwd(ident, &passwd, 0, 0) != ERR_NOERROR) goto bail_out;
-#endif
+    eflag = km_get_passwd(ident, pw_ctxt, &passwd, 0, 0);
+    if (eflag != ERR_NOERROR) goto bail_out;
 
     /* read key header: */
     fread((void*)hbuff, (size_t)1, kmgcryossl_maglen, fp_key);
@@ -671,14 +664,22 @@ static int kmgcryossl_get_key(const char *ident, const keyinfo_t *keyinfo,
     ofs = 0; idx = 0; kbad = 0;
     if (pos > 0) ofs = buff[pos - 1]; else kbad |= 1;
     if (ofs > cblksz) kbad |= 1;
-    while (idx<ofs && !kbad) {
+    while (idx < ofs && !kbad) {
         kbad |= (buff[--pos] != ofs);
         ++idx;
     }
     if (kbad) {
-        fprintf(stderr, _("corrupted keyfile (openssl-compat, ofs=%u,idx=%u)\n"),
-                (unsigned)ofs, (unsigned)idx);
-        eflag = ERR_BADFILE;
+        switch (pw_ctxt->debug_level) {
+            case 0:
+                fprintf(stderr, _("password mismatch when extracting key\n"));
+                break;
+            case 1:     /* fall through... */
+            default:
+                fprintf(stderr, _("checksum mismatch in keyfile (openssl-compat, ofs=%u,idx=%u)\n"),
+                        (unsigned)ofs, (unsigned)idx);
+                break;
+        }
+        eflag = ERR_BADDECRYPT;
     }
     *keylen = pos;
 
@@ -691,19 +692,21 @@ static int kmgcryossl_get_key(const char *ident, const keyinfo_t *keyinfo,
     if (ferror(fp_key) != 0) {
         fprintf(stderr, _("key-extraction failed for \"%s\"\n"),
                 keyinfo->filename);
-        eflag = ERR_BADDECRYPT;
+        eflag = ERR_BADFILE;
     }
 
   bail_out:
 
-    if (buff != NULL) sec_free(buff);
-    if (hbuff != NULL) sec_free(hbuff);
+    if (buff != NULL) sec_free((void*)buff);
+    if (passwd != NULL) sec_free((void*)passwd);
+    if (hbuff != NULL) sec_free((void*)hbuff);
 
     return eflag;
 }
 
 
 static int kmgcryossl_put_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
     /* store key in OpenSSL-compatible file via libgcrypt */
 {   gcry_cipher_hd_t chd;
@@ -716,13 +719,8 @@ static int kmgcryossl_put_key(const char *ident, const keyinfo_t *keyinfo,
     if (eflag != ERR_NOERROR) goto bail_out;
     gcry_cipher_algo_info(cipher, GCRYCTL_GET_BLKLEN, NULL, &cblksz);
 
-#ifdef TESTING
-    passwd = sec_realloc((void*)passwd, (size_t)1024);
-    strncpy(passwd, (test_ctxtptr->argpassword[1] != NULL ? test_ctxtptr->argpassword[1] : ""),
-            1024);
-#else
-    if (km_get_passwd(ident, &passwd, 1, 1) != ERR_NOERROR) goto bail_out;
-#endif
+    eflag = km_get_passwd(ident, pw_ctxt, &passwd, 1, 1);
+    if (eflag != ERR_NOERROR) goto bail_out;
 
     /* write key header: */
     wrcnt = 0;
@@ -752,14 +750,14 @@ static int kmgcryossl_put_key(const char *ident, const keyinfo_t *keyinfo,
 
     if (wrcnt != (2 + buffsz / cblksz)) {
         fprintf(stderr, _("failed to create new key file\n"));
-	fprintf(stderr, "wrcnt=%d\n", (int)wrcnt);
+        fprintf(stderr, "wrcnt=%d\n", (int)wrcnt);
         eflag = ERR_BADFILE;
         goto bail_out;
     }
 
   bail_out:
-    if (buff != NULL) sec_free(buff);
-    if (passwd != NULL) sec_free(passwd);
+    if (buff != NULL) sec_free((void*)buff);
+    if (passwd != NULL) sec_free((void*)passwd);
 
     return eflag;
 }
@@ -910,5 +908,5 @@ keymanager_t *kmgcry_gethandle()
 #endif  /* !AS_MODULE */
 
 /*
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
