@@ -1,7 +1,7 @@
 /*
  *  methods for encryption/security mechanisms for cryptmount
- *  $Revision: 171 $, $Date: 2007-07-17 20:55:35 +0100 (Tue, 17 Jul 2007) $
- *  Copyright 2005-2007 RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -110,6 +106,7 @@ static int kmraw_needs_pw(const keyinfo_t *keyinf)
 
 
 static int kmraw_get_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             unsigned char **key, int *keylen, FILE *fp_key)
     /* extract key from unencrypted (plain) file */
 {   enum { BUFFSZ=512 };
@@ -141,6 +138,7 @@ static int kmraw_get_key(const char *ident, const keyinfo_t *keyinfo,
     if (ferror(fp_key) != 0) {
         fprintf(stderr, _("key-extraction failed for \"%s\"\n"),
                 keyinfo->filename);
+        /* this is a trivial case of decryption failure: */
         eflag = ERR_BADDECRYPT;
     }
 
@@ -151,6 +149,7 @@ static int kmraw_get_key(const char *ident, const keyinfo_t *keyinfo,
 
 
 static int kmraw_put_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
     /* store key in unencrypted (plain) file */
 {   int eflag=ERR_NOERROR;
@@ -248,7 +247,6 @@ static void build_keymgrs(void)
 
     ptr = &keymgrs;
     ptr = add_keymgr(ptr, kmblti_gethandle());
-    ptr = add_keymgr(ptr, kmssl_gethandle());
     ptr = add_keymgr(ptr, kmgcry_gethandle());
     ptr = add_keymgr(ptr, &keymgr_raw);
 }
@@ -321,9 +319,10 @@ int free_keymanagers(void)
 
 
 int get_key(const char *ident, const keyinfo_t *keyinfo,
-            unsigned char **key, int *keylen)
+            const km_pw_context_t *pw_ctxt, unsigned char **key, int *keylen)
 {   keymanager_t *km;
     FILE *fp=NULL;
+    unsigned attempts=0;
     int eflag=ERR_NOERROR;
 
     if (keyinfo == NULL || keyinfo->filename == NULL) {
@@ -342,8 +341,11 @@ int get_key(const char *ident, const keyinfo_t *keyinfo,
     }
 
     if ((km = get_keymanager(keyinfo, fp)) != NULL) {
-        (void)fseek(fp, 0L, SEEK_SET);
-        eflag = km->get_key(ident, keyinfo, key, keylen, fp);
+        do {
+            (void)fseek(fp, 0L, SEEK_SET);
+            eflag = km->get_key(ident, keyinfo, pw_ctxt, key, keylen, fp);
+            if (eflag == ERR_BADDECRYPT) sleep(1);
+        } while (++attempts < keyinfo->retries && eflag == ERR_BADDECRYPT);
     } else {
         fprintf(stderr,
                 _("unrecognized key format (%s) for target \"%s\"\n"),
@@ -359,6 +361,7 @@ int get_key(const char *ident, const keyinfo_t *keyinfo,
 
 
 int put_key(const char *ident, const keyinfo_t *keyinfo,
+            const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
 {   keymanager_t *km;
     int eflag = ERR_NOERROR;
@@ -369,7 +372,7 @@ int put_key(const char *ident, const keyinfo_t *keyinfo,
     }
 
     if ((km = get_keymanager(keyinfo, NULL)) != NULL) {
-        eflag = km->put_key(ident, keyinfo, key, keylen, fp_key);
+        eflag = km->put_key(ident, keyinfo, pw_ctxt, key, keylen, fp_key);
     } else {
         fprintf(stderr,
                 _("unrecognized key format (%s) for target \"%s\"\n"),
@@ -445,14 +448,14 @@ int km_test_keyrw(void)
             /* write key to file: */
             fp = tmpfile();
             if (fp == NULL) CM_TEST_ABORT(context);
-            i = km->put_key("TEST-OUT", &keyinfo, key0, keylen, fp);
+            i = km->put_key("TEST-OUT", &keyinfo, NULL, key0, keylen, fp);
             CM_ASSERT_EQUAL(ERR_NOERROR, i);
 
             key1 = NULL; keylen1 = -keylen;
 
             /* try reading key back from file: */
             rewind(fp);
-            i = km->get_key("TEST-IN", &keyinfo, &key1, &keylen1, fp);
+            i = km->get_key("TEST-IN", &keyinfo, NULL, &key1, &keylen1, fp);
             CM_ASSERT_EQUAL(ERR_NOERROR, i);
             CM_ASSERT_EQUAL(keylen, keylen1);
             CM_ASSERT_DIFFERENT(key0, key1);
@@ -662,5 +665,5 @@ int cm_mutex_unlock(void)
 
 
 /*
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
