@@ -1,7 +1,7 @@
 /*
  *  declarations for encryption/security mechanisms for cryptmount
- *  $Revision: 157 $, $Date: 2007-04-10 07:26:21 +0100 (Tue, 10 Apr 2007) $
- *  Copyright 2005-2007, RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 
@@ -33,6 +29,7 @@
 struct keyinfo;
 struct cment;
 struct cm_testinfo;
+struct km_pw_context;
 
 typedef struct keymanager {
     const char *ident;
@@ -52,10 +49,12 @@ typedef struct keymanager {
 
     /* extract encrypted key from file: */
     int (*get_key)(const char *ident, const struct keyinfo *keyinfo,
+                    const struct km_pw_context *pw_ctxt,
                     unsigned char **key, int *keylen, FILE *fp_key);
 
     /* write encrypted key into file: */
     int (*put_key)(const char *ident, const struct keyinfo *keyinfo,
+                    const struct km_pw_context *pw_ctxt,
                     const unsigned char *key, const int keylen, FILE *fp_key);
 
     /* message-digest computation (used as source of entropy): */
@@ -79,15 +78,16 @@ keymanager_t *get_keymanager(const struct keyinfo *keyinfo, FILE *fp_key);
 
 
 keymanager_t *kmblti_gethandle(void);
-keymanager_t *kmssl_gethandle(void);
 keymanager_t *kmgcry_gethandle(void);
 keymanager_t *init_keymanager(keymanager_t *km);
 int free_keymanagers(void);
 
 int is_keysafe(const struct keyinfo *keyinfo);
 int get_key(const char *ident, const struct keyinfo *keyinfo,
+            const struct km_pw_context *pw_ctxt,
             unsigned char **key, int *keylen);
 int put_key(const char *ident, const struct keyinfo *keyinfo,
+            const struct km_pw_context *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key);
 size_t mk_key_string(const unsigned char *key, const size_t keylen,
             char *buff);
@@ -116,5 +116,5 @@ int cm_mutex_unlock(void);
 #endif  /* _ARMOUR_H */
 
 /*
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
