@@ -1,6 +1,6 @@
 /*
  *  cryptmount - a utility for user-level mounting of encrypted filesystems
- *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  $Revision: 213 $, $Date: 2008-07-26 07:28:58 +0100 (Sat, 26 Jul 2008) $
  *  (C)Copyright 2005-2008, RW Penney
  */
 
@@ -121,7 +121,7 @@ usage: cryptmount [OPTION [target ...]]\n\
     --swapoff <target>\n\
     --version\n\
 \n\
-  please report bugs to cryptmount@rwpenney.org.uk\n\
+  please report bugs to <cryptmount@rwpenney.org.uk>\n\
 ");
 
 
@@ -608,7 +608,7 @@ static int do_passwd(const km_pw_context_t *pw_ctxt, const cment_t *cment)
           || rename(cment->key.filename, oldfname) != 0
           || chown(oldfname, 0, 0) != 0
           || chmod(oldfname, S_IRUSR | S_IWUSR) != 0) {
-            fprintf(stderr, _("retiring old key (%s -> %s) failed)"),
+            fprintf(stderr, _("retiring old key (%s -> %s) failed\n"),
                     cment->key.filename, oldfname);
             goto bail_out;
         }
@@ -616,7 +616,7 @@ static int do_passwd(const km_pw_context_t *pw_ctxt, const cment_t *cment)
         if (rename(newfname, cment->key.filename) != 0
           || chown(cment->key.filename, sbuff.st_uid, sbuff.st_gid) != 0
           || chmod(cment->key.filename, sbuff.st_mode) != 0) {
-            fprintf(stderr, _("installing new key (%s -> %s) failed"),
+            fprintf(stderr, _("installing new key (%s -> %s) failed\n"),
                     newfname, cment->key.filename);
             goto bail_out;
         }
