@@ -1,7 +1,7 @@
 /*
  *  device-mapper utilities for cryptmount
- *  $Revision: 134 $, $Date: 2007-02-19 17:18:07 +0000 (Mon, 19 Feb 2007) $
- *  Copyright 2005-2007, RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -129,19 +125,19 @@ int devmap_dependencies(const char *ident, unsigned *count, dev_t **devids)
     int eflag=ERR_NOERROR;
 
     if ((dmt = devmap_prepare(DM_DEVICE_DEPS, ident)) == NULL) {
-	fprintf(stderr, "failed to initialize device-mapper task\n");
-	eflag = ERR_DMSETUP;
-	goto bail_out;
+        fprintf(stderr, "failed to initialize device-mapper task\n");
+        eflag = ERR_DMSETUP;
+        goto bail_out;
     }
     if (!dm_task_run(dmt)) {
-	fprintf(stderr, "device-mapper task failed\n");
-	eflag = ERR_DMSETUP;
-	goto bail_out;
+        fprintf(stderr, "device-mapper task failed\n");
+        eflag = ERR_DMSETUP;
+        goto bail_out;
     }
 
     if ((deps = dm_task_get_deps(dmt)) == NULL) {
-	eflag = ERR_DMSETUP;
-	goto bail_out;
+        eflag = ERR_DMSETUP;
+        goto bail_out;
     }
 
     /* copy device info into fresh array: */
@@ -230,5 +226,5 @@ int is_configured(const char *ident, struct dm_info *dminfo)
 
 
 /*
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
