@@ -1,7 +1,7 @@
 /*
  *  loopback-device utilities for cryptmount
- *  $Revision: 161 $, $Date: 2007-05-05 22:53:24 +0100 (Sat, 05 May 2007) $
- *  Copyright 2005-2007, RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -83,17 +79,17 @@ int loop_findfree(char *buff, size_t buffsz)
     for (min=0; min<256u && !found; ++min) {
         for (idx=0; loop_formats[idx]!=NULL && !found; ++idx) {
             sprintf(str, loop_formats[idx], min);
-	    if (stat(str, &sbuff) || !S_ISBLK(sbuff.st_mode)) continue;
-	    devfd = open(str, O_RDONLY);
-	    if (devfd < 0) continue;
-	    if (ioctl(devfd, MY_LOOPGETSTATUS, &linfo) && errno == ENXIO) {
-		found = 1;
+            if (stat(str, &sbuff) || !S_ISBLK(sbuff.st_mode)) continue;
+            devfd = open(str, O_RDONLY);
+            if (devfd < 0) continue;
+            if (ioctl(devfd, MY_LOOPGETSTATUS, &linfo) && errno == ENXIO) {
+            found = 1;
 #ifdef DEBUG
                 fprintf(stderr,"loop device \"%s\" is available\n", str);
 #endif
-	    }
-	    close(devfd);
-	}
+            }
+            close(devfd);
+        }
     }
 
     if (found && buff != NULL) strncpy(buff, str, buffsz);
@@ -104,7 +100,7 @@ int loop_findfree(char *buff, size_t buffsz)
 
 int loop_setup(const char *dev, const char *file, int flags)
     /* setup loopback device to point to regular file */
-{   int devfd=-1,filefd=-1,eflag=ERR_NOERROR;
+{   int devfd=-1, filefd=-1, eflag=ERR_NOERROR;
     my_loopinfo_t lpinfo;
 
     memset((void*)&lpinfo, 0, sizeof(lpinfo));
@@ -127,7 +123,7 @@ int loop_setup(const char *dev, const char *file, int flags)
 
     if (ioctl(devfd, LOOP_SET_FD, filefd)
       || ioctl(devfd, MY_LOOPSETSTATUS, &lpinfo)) {
-        fprintf(stderr,"ioctl() failed on \"%s\"\n", dev);
+        fprintf(stderr, "LOOP_SET_FD ioctl() failed on \"%s\"\n", dev);
         eflag = ERR_BADIOCTL;
         goto bail_out;
     }
@@ -154,7 +150,7 @@ int loop_destroy(const char *dev)
     }
 
     if (ioctl(devfd, LOOP_CLR_FD, 0)) {
-        fprintf(stderr, "ioctl() failed on \"%s\"\n", dev);
+        fprintf(stderr, "LOOP_CLR_FD ioctl() failed on \"%s\"\n", dev);
         eflag = ERR_BADIOCTL;
         goto bail_out;
     }
@@ -210,5 +206,5 @@ int loop_dellist(unsigned devcnt, const dev_t *devids)
 }
 
 /*
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
