@@ -1,7 +1,7 @@
 /*
  *  config-table and mount-table utilities for cryptmount
- *  $Revision: 161 $, $Date: 2007-05-05 22:53:24 +0100 (Sat, 05 May 2007) $
- *  Copyright 2005-2007, RW Penney
+ *  $Revision: 202 $, $Date: 2008-06-07 10:29:31 +0100 (Sat, 07 Jun 2008) $
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -72,33 +68,40 @@ static cment_t *parse_stream(FILE *fp, const char *cfgname);
 */
 
 
-cment_t *alloc_cment(void)
+cment_t *alloc_cment(const cment_t *prototype)
     /* allocate storage for a target-structure */
 {   cment_t *cment;
 
+#define DFLT_OR_PROTO(dflt, proto) \
+        (prototype == NULL ? (dflt) : (proto))
+
     cment = (cment_t*)malloc(sizeof(cment_t));
 
     cment->ident = NULL;
-    cment->flags = FLG_DEFAULTS;
+    cment->flags = DFLT_OR_PROTO(FLG_DEFAULTS, prototype->flags);
 
     cment->dev = NULL;
     cment->start = 0; cment->length = -1;
     cment->dir = NULL;
-    cment->fstype = NULL;
-    cment->fsoptions = NULL;
+    cment->fstype = DFLT_OR_PROTO(NULL, cm_strdup(prototype->fstype));
+    cment->fsoptions = DFLT_OR_PROTO(NULL, cm_strdup(prototype->fsoptions));
     cment->loopdev = NULL;
 
-    cment->cipher = cm_strdup(DFLT_CIPHER);
+    cment->cipher = DFLT_OR_PROTO(cm_strdup(DFLT_CIPHER),
+                                cm_strdup(prototype->cipher));
     cment->ivoffset = 0;
 
-    cment->key.format = NULL;
+    cment->key.format = DFLT_OR_PROTO(NULL, cm_strdup(prototype->key.format));
     cment->key.filename = NULL;
-    cment->key.digestalg = NULL;
-    cment->key.cipheralg = NULL;
-    cment->key.maxlen = -1L;
+    cment->key.digestalg = DFLT_OR_PROTO(NULL, cm_strdup(prototype->key.digestalg));
+    cment->key.cipheralg = DFLT_OR_PROTO(NULL, cm_strdup(prototype->key.cipheralg));
+    cment->key.maxlen = DFLT_OR_PROTO(-1L, prototype->key.maxlen);
+    cment->key.retries = DFLT_OR_PROTO(1U, prototype->key.retries);
 
     cment->nx = NULL;
 
+#undef DFLT_OR_PROTO
+
     return cment;
 }
 
@@ -165,30 +168,21 @@ static int proc_string(void *ptr, const char *src)
 }
 
 
-static int proc_long(void *ptr, const char *src)
-    /* process var=val entry in config-table for "long" type */
-{   long ql, *addr=(long*)ptr;
-
-    if (sscanf(src, "%ld", &ql) == 1) {
-        *addr = ql;
-        return 0;
+#define PROC_VARVAL(FN_NAME, TYPE, FMT)                         \
+    static int FN_NAME(void *ptr, const char *src)              \
+        /* process var=val entry in config-table for "TYPE" */  \
+    {   TYPE qv, *addr=(TYPE*)ptr;                              \
+        if (sscanf(src, FMT, &qv) == 1) {                       \
+            *addr = qv; return 0;                               \
+        }                                                       \
+        return 1;                                               \
     }
 
-    return 1;
-}
+PROC_VARVAL(proc_unsigned, unsigned, "%u")
+PROC_VARVAL(proc_long, long, "%ld")
+PROC_VARVAL(proc_int64, int64_t, "%" SCNi64)
 
-
-static int proc_int64(void *ptr, const char *src)
-    /* process var=val entry in config-table for "int64" type */
-{   int64_t ql, *addr=(int64_t*)ptr;
-
-    if (sscanf(src, "%" SCNi64, &ql) == 1) {
-        *addr = ql;
-        return 0;
-    }
-
-    return 1;
-}
+#undef PROC_VARVAL
 
 
 int proc_flags(void *ptr, const char *src)
@@ -256,6 +250,7 @@ static void read_token(char *buff, unsigned *t_state, cment_t *cment)
         { "keyhash",        OFFSET(key.digestalg),  proc_string },
         { "keycipher",      OFFSET(key.cipheralg),  proc_string },
         { "keymaxlen",      OFFSET(key.maxlen),     proc_long },
+        { "passwdretries",  OFFSET(key.retries),    proc_unsigned },
         { NULL, 0, NULL }
     };
 #undef OFFSET
@@ -309,11 +304,11 @@ cment_t *parse_stream(FILE *fp, const char *cfgname)
     unsigned pos=0,bufflen=0;
     unsigned c_state,t_state;
     char *buff=NULL;
-    cment_t *head=NULL,**cmp=&head,*cment=NULL;
+    cment_t *head=NULL, **cmp=&head, *cment=NULL, *prototype=NULL;
 
     c_state = C_SPACE;
     t_state = T_IDENT;
-    cment = alloc_cment();
+    cment = alloc_cment(prototype);
 
     while (!feof(fp) && t_state != T_ERROR) {
         ch = fgetc(fp);
@@ -357,9 +352,19 @@ cment_t *parse_stream(FILE *fp, const char *cfgname)
 
         literal = 0;
         if (t_state == T_RBRACE) {
-            *cmp = cment;
-            cmp = &cment->nx;
-            cment = alloc_cment();
+            /* parsing has reached end of target definition */
+
+            if (strcmp(cment->ident, "_DEFAULTS_") == 0) {
+                /* new target definition is set of default values */
+                if (prototype != NULL) free_cment(prototype);
+                prototype = cment;
+            } else {
+                /* new target definition is genuine target */
+                *cmp = cment;
+                cmp = &cment->nx;
+            }
+
+            cment = alloc_cment(prototype);
             t_state = T_IDENT;
         }
     }
@@ -369,6 +374,7 @@ cment_t *parse_stream(FILE *fp, const char *cfgname)
                 cfgname, lineno);
     }
 
+    if (prototype != NULL) free_cment(prototype);
     if (cment != NULL) free_cment(cment);
     if (buff != NULL) free((void*)buff);
 
@@ -642,5 +648,5 @@ int put_tgtstatus(const cment_t *cment, const tgtstat_t *newstat)
 
 /*
  *  tables.c
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
