@@ -1,7 +1,7 @@
 /*
  *  miscellaneous utilitie functions for cryptmount
  *  $Revision: 134 $, $Date: 2007-02-19 17:18:07 +0000 (Mon, 19 Feb 2007) $
- *  Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
 
 /*
@@ -12,18 +12,14 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    As a special exemption, permission is granted to link cryptmount
-    with the OpenSSL project's "OpenSSL" library and distribute
-    the linked code without invoking clause 2(b) of the GNU GPL version 2.
-
     cryptmount is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with cryptmount; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -36,6 +32,9 @@
 #include <sys/times.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#if HAVE_TERMIOS
+#  include <termios.h>
+#endif
 #include <unistd.h>
 
 #include "cryptmount.h"
@@ -238,37 +237,107 @@ int get_randkey(unsigned char *buff, size_t len)
 }
 
 
-int km_get_passwd(const char *ident, char **passwd, int isnew, int verify)
+ssize_t cm_ttygetpasswd(const char *prompt, char **buff)
+    /* read password from standard input terminal */
+{   ssize_t pwlen=0;
+#if HAVE_TERMIOS
+    struct termios oldttystate, newttystate;
+    int echook=1;
+    char tmppass[2048];
+#else
+    char *tmppass=NULL;
+#endif
+
+#if HAVE_TERMIOS
+    if (tcgetattr(fileno(stdin), &oldttystate) != 0) echook = 0;
+    newttystate = oldttystate;
+    newttystate.c_lflag &= ~ECHO;
+    if (tcsetattr(fileno(stdin), TCSAFLUSH, &newttystate) != 0) echook = 0;
+    if (tcgetattr(fileno(stdin), &newttystate) != 0
+      || (newttystate.c_lflag & ECHO) != 0) echook = 0;
+    if (echook) {
+        printf(prompt);
+        fgets(tmppass, (int)sizeof(tmppass), stdin);
+        pwlen = strlen(tmppass);
+        if (pwlen > 0 && tmppass[pwlen-1] == '\n') {
+            tmppass[--pwlen] = '\0'; }
+        *buff = sec_realloc((void*)*buff, (size_t)(pwlen+1));
+        strcpy(*buff, tmppass);
+        mem_cleanse((unsigned char*)tmppass, sizeof(tmppass));
+        tcsetattr(fileno(stdin), TCSAFLUSH, &oldttystate);
+        printf("\n");
+    } else {
+        fprintf(stderr, _("failed to turn off keyboard echoing on terminal\n"));
+        pwlen = -1;
+    }
+#else
+    tmppass = getpass(prompt);
+    pwlen = strlen(tmppass);
+    *buff = sec_realloc((void*)*buff, (size_t)(pwlen+1));
+    strcpy(*buff, tmppass);
+    mem_cleanse((unsigned char*)tmppass, (size_t)(pwlen+1));
+#endif  /* !HAVE_TERMIOS */
+
+    return pwlen;
+}
+
+
+int km_get_passwd(const char *ident, const km_pw_context_t *pw_ctxt,
+                char **passwd, int isnew, int verify)
     /* read password from terminal, possibly asking for confirmation */
 {   enum { BUFFSZ=2048 };
-    char *tmppass, buff[BUFFSZ];
-    size_t plen;
+    char *tmppass=NULL;
+    ssize_t plen=0;
     int eflag=ERR_NOERROR;
 
-    snprintf(buff, sizeof(buff),
-            (isnew ? _("enter new password for target \"%s\": ")
-                : _("enter password for target \"%s\": ")),
-            ident);
+    if (pw_ctxt == NULL || pw_ctxt->fd_pw_source == NULL) {
+#ifndef TESTING
+        /* read (+confirm) password from terminal: */
+	char prompt[BUFFSZ];
+        snprintf(prompt, sizeof(prompt),
+                (isnew ? _("enter new password for target \"%s\": ")
+                    : _("enter password for target \"%s\": ")),
+                ident);
 
-    tmppass = getpass(buff);
-    plen = strlen(tmppass);
-    *passwd = (char*)sec_realloc((void*)*passwd, (plen + 1));
-    strcpy(*passwd, tmppass);
-    mem_cleanse((unsigned char*)tmppass, plen + 1);
-
-    if (verify) {
-        snprintf(buff, sizeof(buff), _("confirm password: "));
-        tmppass = getpass(buff);
-        plen = strlen(tmppass);
-        if (strcmp(*passwd, tmppass) != 0) {
-            fprintf(stderr, _("password mismatch\n"));
-            sec_free(*passwd);
-            *passwd = NULL;
+        if (cm_ttygetpasswd(prompt, passwd) < 0) {
             eflag = ERR_BADPASSWD;
+            goto bail_out;
         }
-        mem_cleanse((unsigned char*)tmppass, plen);
+
+        if (verify) {
+            snprintf(prompt, sizeof(prompt), _("confirm password: "));
+            plen = cm_ttygetpasswd(prompt, &tmppass);
+            if (strcmp(*passwd, tmppass) != 0) {
+                fprintf(stderr, _("password mismatch\n"));
+                sec_free(*passwd);
+                *passwd = NULL;
+                eflag = ERR_BADPASSWD;
+            }
+        }
+#else   /* TESTING */
+        /* read passwords passed in via command-line arguments: */
+        const char *argpw;
+        argpw = (pw_ctxt != NULL ? pw_ctxt->argpasswd[(isnew ? 1 : 0)] : NULL);
+        *passwd = (char*)sec_realloc((void*)*passwd, (size_t)1024);
+        strncpy(*passwd, (argpw != NULL ? argpw : ""), (size_t)1024);
+#endif
+    } else {
+        /* read password (once only) from input stream: */
+        tmppass = (char*)sec_realloc(tmppass, (size_t)BUFFSZ);
+        fgets(tmppass, BUFFSZ, pw_ctxt->fd_pw_source);
+
+        /* remove trailing carriage-return(s): */
+        plen = strlen(tmppass);
+        while (plen > 0 && tmppass[plen-1] == '\n') tmppass[--plen] = '\0';
+
+        *passwd = (char*)sec_realloc(*passwd, (plen + 1));
+        strcpy(*passwd, tmppass);
     }
 
+  bail_out:
+
+    sec_free((void*)tmppass);
+
     return eflag;
 }
 
@@ -515,5 +584,5 @@ int ut_test_sha1()
 
 /*
  *  utils.c
- *  (C)Copyright 2005-2007, RW Penney
+ *  (C)Copyright 2005-2008, RW Penney
  */
